package javax.swing.plaf.nimbus;

import javax.swing.JComponent;
import java.awt.Graphics2D;
import java.awt.Color;
import java.awt.geom.Ellipse2D;
import java.awt.geom.RoundRectangle2D;
import java.awt.geom.Rectangle2D;
import java.awt.geom.Path2D;

final class TreeCellPainter extends AbstractRegionPainter
{
    static final int BACKGROUND_ENABLED = 1;
    static final int BACKGROUND_ENABLED_FOCUSED = 2;
    static final int BACKGROUND_ENABLED_SELECTED = 3;
    static final int BACKGROUND_SELECTED_FOCUSED = 4;
    private int state;
    private AbstractRegionPainter.PaintContext ctx;
    private Path2D path;
    private Rectangle2D rect;
    private RoundRectangle2D roundRect;
    private Ellipse2D ellipse;
    private Color color1;
    private Color color2;
    private Object[] componentColors;
    
    public TreeCellPainter(AbstractRegionPainter.PaintContext ctx, int state) {
        this.path = new Path2D.Float();
        this.rect = new Rectangle2D.Float(0.0f, 0.0f, 0.0f, 0.0f);
        this.roundRect = new RoundRectangle2D.Float(0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f);
        this.ellipse = new Ellipse2D.Float(0.0f, 0.0f, 0.0f, 0.0f);
        this.color1 = this.decodeColor("nimbusFocus", 0.0f, 0.0f, 0.0f, 0);
        this.color2 = this.decodeColor("nimbusSelectionBackground", 0.0f, 0.0f, 0.0f, 0);
        this.state = state;
        this.ctx = ctx;
    }
    
    @Override
    protected void doPaint(Graphics2D graphics2D, JComponent component, int n, int n2, Object[] componentColors) {
        this.componentColors = componentColors;
        switch (this.state) {
            case 2: {
                this.paintBackgroundEnabledAndFocused(graphics2D);
                break;
            }
            case 3: {
                this.paintBackgroundEnabledAndSelected(graphics2D);
                break;
            }
            case 4: {
                this.paintBackgroundSelectedAndFocused(graphics2D);
                break;
            }
        }
    }
    
    @Override
    protected final AbstractRegionPainter.PaintContext getPaintContext() {
        return this.ctx;
    }
    
    private void paintBackgroundEnabledAndFocused(Graphics2D graphics2D) {
        this.path = this.decodePath1();
        graphics2D.setPaint(this.color1);
        graphics2D.fill(this.path);
    }
    
    private void paintBackgroundEnabledAndSelected(Graphics2D graphics2D) {
        this.rect = this.decodeRect1();
        graphics2D.setPaint(this.color2);
        graphics2D.fill(this.rect);
    }
    
    private void paintBackgroundSelectedAndFocused(Graphics2D graphics2D) {
        this.rect = this.decodeRect1();
        graphics2D.setPaint(this.color2);
        graphics2D.fill(this.rect);
        this.path = this.decodePath1();
        graphics2D.setPaint(this.color1);
        graphics2D.fill(this.path);
    }
    
    private Path2D decodePath1() {
        this.path.reset();
        this.path.moveTo((double)this.decodeX(0.0f), (double)this.decodeY(0.0f));
        this.path.lineTo((double)this.decodeX(0.0f), (double)this.decodeY(3.0f));
        this.path.lineTo((double)this.decodeX(3.0f), (double)this.decodeY(3.0f));
        this.path.lineTo((double)this.decodeX(3.0f), (double)this.decodeY(0.0f));
        this.path.lineTo((double)this.decodeX(0.24000001f), (double)this.decodeY(0.0f));
        this.path.lineTo((double)this.decodeX(0.24000001f), (double)this.decodeY(0.24000001f));
        this.path.lineTo((double)this.decodeX(2.7600007f), (double)this.decodeY(0.24000001f));
        this.path.lineTo((double)this.decodeX(2.7600007f), (double)this.decodeY(2.7599998f));
        this.path.lineTo((double)this.decodeX(0.24000001f), (double)this.decodeY(2.7599998f));
        this.path.lineTo((double)this.decodeX(0.24000001f), (double)this.decodeY(0.0f));
        this.path.lineTo((double)this.decodeX(0.0f), (double)this.decodeY(0.0f));
        this.path.closePath();
        return this.path;
    }
    
    private Rectangle2D decodeRect1() {
        this.rect.setRect((double)this.decodeX(0.0f), (double)this.decodeY(0.0f), (double)(this.decodeX(3.0f) - this.decodeX(0.0f)), (double)(this.decodeY(3.0f) - this.decodeY(0.0f)));
        return this.rect;
    }
}
